#
# spec file for package python-copr-cli
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-copr-cli
Version:        2.0
Release:        1.3
Summary:        Copr cli
License:        GPL-2.0-or-later
URL:            https://github.com/fedora-copr/copr
Source:         https://files.pythonhosted.org/packages/source/c/copr-cli/copr-cli-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Jinja2
Requires:       python-copr >= 1.116
Requires:       python-humanize
Requires:       python-setuptools
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Jinja2}
BuildRequires:  %{python_module copr >= 1.116}
BuildRequires:  %{python_module humanize}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module responses}
# /SECTION
Requires(post): update-alternatives
Requires(postun): update-alternatives
%python_subpackages

%description
CLI tool to run copr.

%prep
%autosetup -p1 -n copr-cli-%{version}

sed -i '1{/#!/d}' copr_cli/package_build_order.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/copr-cli
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%post
%python_install_alternative copr-cli

%postun
%python_uninstall_alternative copr-cli

%files %{python_files}
%license LICENSE
%python_alternative %{_bindir}/copr-cli
%{python_sitelib}/copr_cli
%{python_sitelib}/copr_cli-%{version}.dist-info

%changelog
* Thu Dec 12 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 2.0:
  * no upstream changelog
- remove remove-simplejson.patch, as upstream removed simplejson
* Sat Apr 20 2024 Dirk Müller <dmueller@suse.com>
- update to 1.111:
  * no upstream changelog
* Fri Sep  8 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.110:
  * No upstream changelog.
- Fiddle with {Build,}Requires as appropiate.
- Switch to pyproject macros.
- Refresh patch remove-simplejson.patch
* Fri Feb 10 2023 Matej Cepl <mcepl@suse.com>
- Add remove-simplejson.patch (gh#fedora-copr/copr#2539).
* Fri Feb 10 2023 Dirk Müller <dmueller@suse.com>
- update to 1.105:
  * More understandable module hotfixes description
  * Add options to download only built RPMs/spec files
  * Use the --dirname parameter for copr-cli monitor
  * Disable appstream by default
* Wed Dec  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 1.104:
  - move to GitHub home page
  - add parameter for custom method repos
* Mon Sep 26 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to Version 1.103:
  - The previous release brought several enhancements and fixes for the stats calculation mechanism but it wasn’t quite enough.
  - This release comes with some final follow-ups. We are hoping to start counting the RPM downloads shortly after.
  Minor UI improvements
  - In the project settings, the “Edit” button will now show only for enabled chroots
  - The build detail page now shows the build timeout value
  - If a build is a part of a batch, the detail page now shows a link for it
  - The user detail page now shows a link for the /user/repositories/
  Bugfixes
  [#2294] - Show correct distribution images based on their OS family
  [#2293], RHBZ 2081915 - Fixed copr-frontend FTBFS for F37/Rawhide
  RHBZ 2113156 - Fixed copr-keygen FTBFS for F37/Rawhide
* Fri Apr 22 2022 Matej Cepl <mcepl@suse.com>
- Update to 1.100 (changes for all copr packages, not only copr-cli):
  - Bugfixes
  - Kerberos/GSSAPI authentication for API and copr-cli
  - Copr-cli re-tries connections with Copr Frontend
  - Large queue improvements
  - More copr-cli options for editing chroots
  - Signing packages with SHA256
  - Remote refs in committish
  - Removing unused tarballs
  - More human-readable validation errors in APIv3
  - Basic build tagging
  - Webhook rebuilds are background jobs now
  - Searching by attributes
  - APIv3 /monitor route
  - The “Rebuild all” packages feature enhanced
  - Builder VMs priority
  - Query built RPM results via API
  - Pull request CoprDirs are automatically deleted after inactivity
  - Showing two latest Copr-related articles
  - Specify copr-cli output format
  - IPv6 support
  - Isolation configuration per-chroot
  - Submit build with excluded chroots
  - EOL chroot management
  - Disabling modules in buildroot
  - New mock –isolation option
  - EOL repository management
  - Searching by build ID
* Tue Nov 17 2020 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.90
